.. _spider_delinski.at:

delinski.at
-----------
Newest restaurants in Wien bookable at `Delinski <https://delinski.at>`_.

Configuration
~~~~~~~~~~~~~
Add ``delinski.at`` to the list of spiders:

.. code-block:: ini

   # List of spiders to run by default, one per line.
   spiders =
     delinski.at
